@@ -1,12 +1,9 @@
 matchit2optimal <- function(treat, X, data, distance, discarded,
                             ratio = 1, verbose=FALSE, ...) {
 
-  if ("optmatch" %in% .packages(all = TRUE))
-    require(optmatch)
-  else {
+  if (!("optmatch" %in% .packages(all = TRUE)))
     install.packages("optmatch", contriburl="http://www.stat.lsa.umich.edu/~bbh/optmatch")
-    require(optmatch)
-  }
+  require(optmatch)
     
   if(verbose)
     cat("Optimal matching... \n")
